<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name></name>
    <message>
        <source>Delete</source>
        <translation type="obsolete">حذف</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="obsolete">ملء الشاشة</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="obsolete">عرض الشرائح</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="obsolete">تصدير</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="obsolete">نسخ</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="obsolete">تفضيل</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="obsolete">عرض في مدير الملفات</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="obsolete">معلومات الصورة</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="obsolete">إستعادة</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>بلا اسم</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>إنشاء</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>ألبوم جديد</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>هل أنت متأكد من حذف هذا الألبوم؟</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>سلة المحذوفات</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>المفضلات</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>استيراد</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>سلة المحذوفات</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>المفضلة</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>أو اسحب الصور هنا</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>استيراد الكل</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>استيراد إلى:</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>استيراد</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>قرص النظام</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>المعرض</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>القرص يعمل حالياً، لا يمكن إخراجه الآن</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>موافق</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>ألبوم جديد</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>تجاهل</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image classification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>الإلبوم</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>إستبدال</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>تصدير</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>الصور</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>المستندات</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>التنزيلات</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>سطح المكتب</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>الفيديوهات</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>الموسيقى</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>الاسم:</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>حفظ إلى:</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>الصيغة</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>الجودة:</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>حفظ</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>اختر مجلدات أخرى</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>موافق</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>اسم الملف لا يمكن أن يكون فارغاً</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>موجود مسبقاً، هل تريد إستبداله؟</translation>
    </message>
</context>
<context>
    <name>DBManager</name>
    <message>
        <source>Screen Capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(copy)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>%1 مساحة القرص</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>الفارغ 1% من القرص</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>%1 مشفّر</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>مساحة القرص 1%</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>حفظ</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>تصدير الصور</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>الغاء</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>يتم الآن الحذف...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>تتم الآن الإستعادة...</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>الغاء</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete this file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot restore it any longer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete %1 files?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot restore them any longer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this file locally?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can restore it in the trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 files locally?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can restore them in the trash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>المعلومات الأساسية</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>التفاصيل</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>استيراد</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 فيديو</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>عرض الشرائح</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>إعادة تسمية</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>تصدير</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>الجهاز</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>المعرض</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>الإلبومات</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>ألبوم جديد</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>الصور</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>ملء الشاشة</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>مساعدة</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>عرض في مدير الملفات</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>عرض الشرائح</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>نسخ</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>اجعل الصورة كخلفية</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>تدوير بإتجاه عقارب الساعة</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>تدوير بعكس إتجاه عقارب الساعة</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>السابق</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>التالي</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>تفضيل</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>عدم التفضيل</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>إعادة تسمية الإلبوم</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>تم حذف الإلبوم “1%”</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>تم الإضافة إلى “1%”</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>تم الاستيراد بنجاح</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>فشل الاستيراد</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>فشل التصدير</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>تم التصدير بنجاح</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>جميع الصور</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>الجداول الزمنية</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>الإلبومات</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>الخروج من وضع ملء الشاشة/عرض الشرائح</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>عرض الإختصارات</translation>
    </message>
    <message>
        <source>View</source>
        <translation>عرض</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>اختيار الكل</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>كبّر الصورة</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>صغّر الصورة</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>ألبوم جديد</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>الذهاب لأعلى الصفحة</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>الذهاب لأسفل الصفحة</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>الإعدادات</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>يتم الآن الاستيراد...</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">حذف</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import interrupted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot add this path, please try another one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The path already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to restore %1 files: file name too long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>فلاش</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>النوع</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>حجم الملف</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>الابعاد</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>تاريخ الإلتقاط</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>تاريخ التعديل</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>وضع العرض</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>برنامج العرض</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>وقت العرض</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>فجوة</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>الطول المركزي</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>الفجوة القصوى</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>وضع القياس المتري</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>التوازن الأبيض</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>التعويضات السريعة</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>طراز الكاميرا</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>طراز العدسة</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>مساحة اللون</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>كلمة مفتاحية</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>قرص النظام</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>تحديد</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>إلغاء التحديد</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1/%2/%3</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>إستعادة</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>الصور</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>الفيديوهات</translation>
    </message>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>تفضيل</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>ادر الصورة بعكس إتجاه عقارب الساعة</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>تدوير بإتجاه عقارب الساعة</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>يتم الآن الاستيراد...</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation>تم اختيار 1 صورة</translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation>تم اختيار 1 فيديو</translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1/%2 items classifyed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scenery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Humans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scene</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plants</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>لا توجد نتائج لبحثك</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>عرض الشرائح</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>نتائج البحث</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation>تم العثور علي 1 صورة</translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 فيديو</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>عرض</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>ملء الشاشة</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>تصدير</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>تفضيل</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>عدم التفضيل</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>أدر الصورة بإتجاه عقارب الساعة</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>ادر الصور بعكس إتجاه عقارب الساعة</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>عرض في مدير الملفات</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>اجعلها كخلفية</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>عرض الشرائح</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>نسخ</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>معلومات الصورة</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>إضافة إلى الإلبوم</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>حذف من الإلبوم</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>إستعادة</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>ألبوم جديد</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>طباعة</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished">الأيام</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 فيديو</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation type="unfinished">المعلومات الأساسية</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation type="unfinished">تاريخ التعديل</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">النوع</translation>
    </message>
    <message>
        <source>File size</source>
        <translation type="unfinished">حجم الملف</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished">تاريخ الإلتقاط</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
